Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: content/child/permissions/permission_dispatcher.h

Issue 1035223003: Rename content::PermissionManager to content::PermissionDispatcher. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review comments Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/child/blink_platform_impl.cc ('k') | content/child/permissions/permission_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/child/permissions/permission_dispatcher.h
diff --git a/content/child/permissions/permission_manager.h b/content/child/permissions/permission_dispatcher.h
similarity index 76%
rename from content/child/permissions/permission_manager.h
rename to content/child/permissions/permission_dispatcher.h
index b445e90c448d0d3a9eb1189d3b9c13e08e7d7e9a..6066c44b7228ddb2f81f06fd444f11555c59c582 100644
--- a/content/child/permissions/permission_manager.h
+++ b/content/child/permissions/permission_dispatcher.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_CHILD_PERMISSIONS_PERMISSION_MANAGER_H_
-#define CONTENT_CHILD_PERMISSIONS_PERMISSION_MANAGER_H_
+#ifndef CONTENT_CHILD_PERMISSIONS_PERMISSION_DISPATCHER_H_
+#define CONTENT_CHILD_PERMISSIONS_PERMISSION_DISPATCHER_H_
#include <string>
@@ -18,17 +18,17 @@ namespace content {
class ServiceRegistry;
-// The PermissionManager is a layer between Blink and the Mojo PermissionService
-// It implements blink::WebPermissionClient. It is being used from workers and
-// frames independently. When called outside of the main thread,
-// QueryPermissionForWorker is meant to be called. It will handle the thread
-// jumping.
-class PermissionManager : public blink::WebPermissionClient {
+// The PermissionDispatcher is a layer between Blink and the Mojo
+// PermissionService. It implements blink::WebPermissionClient. It is being used
+// from workers and frames independently. When called outside of the main
+// thread, QueryPermissionForWorker is meant to be called. It will handle the
+// thread jumping.
+class PermissionDispatcher : public blink::WebPermissionClient {
public:
// The caller must guarantee that |service_registry| will have a lifetime
- // larger than this instance of PermissionManager.
- explicit PermissionManager(ServiceRegistry* service_registry);
- virtual ~PermissionManager();
+ // larger than this instance of PermissionDispatcher.
+ explicit PermissionDispatcher(ServiceRegistry* service_registry);
+ virtual ~PermissionDispatcher();
// blink::WebPermissionClient implementation.
virtual void queryPermission(blink::WebPermissionType type,
@@ -79,9 +79,9 @@ class PermissionManager : public blink::WebPermissionClient {
ServiceRegistry* service_registry_;
PermissionServicePtr permission_service_;
- DISALLOW_COPY_AND_ASSIGN(PermissionManager);
+ DISALLOW_COPY_AND_ASSIGN(PermissionDispatcher);
};
} // namespace content
-#endif // CONTENT_CHILD_PERMISSIONS_PERMISSION_MANAGER_H_
+#endif // CONTENT_CHILD_PERMISSIONS_PERMISSION_DISPATCHER_H_
« no previous file with comments | « content/child/blink_platform_impl.cc ('k') | content/child/permissions/permission_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698